Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type LMatrixSearch ¶
LMatrixSearch contains the search target and and data required for a levenshtein matrix search
func NewLMatrixSearch ¶
func NewLMatrixSearch(library []string, keys []interface{}, caseSensitive bool) *LMatrixSearch
NewLMatrixSearch returns a new LMatrixSerachStruct
func (*LMatrixSearch) GetMatchingKeys ¶
func (s *LMatrixSearch) GetMatchingKeys(searchTerm string, maxDiff int) map[interface{}]int
GetMatchingKeys returns a map of keys which are sufficiently close to the searchTerm paired with their distance
func (*LMatrixSearch) SearchForSubstring ¶
func (s *LMatrixSearch) SearchForSubstring(searchTerm string) []int
SearchForSubstring returns a slice containing match distance for each of the items in the SearchLibrary
Click to show internal directories.
Click to hide internal directories.